@@ -2,7 +2,7 @@ import unittest
 import pandas as pd
 
 # classes
-from excel import Excel, Sheet
+from easierexcel.excel import Excel, Sheet
 
 
 class TestStringMethods(unittest.TestCase):
